==> ruby-rubocop-ast_0.3.0+dfsg.orig.tar.gz: rubocop-ast-0.3.0/spec/rubocop/ast/for_node_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::AST::ForNode do
  let(:for_node) { parse_source(source).ast }

  describe '.new' do
    let(:source) { 'for foo in bar; baz; end' }

    it { expect(for_node.is_a?(described_class)).to be(true) }
  end

  describe '#keyword' do
    let(:source) { 'for foo in bar; baz; end' }

    it { expect(for_node.keyword).to eq('for') }
  end

  describe '#do?' do
    context 'with a do keyword' do
      let(:source) { 'for foo in bar do baz; end' }

      it { expect(for_node.do?).to be_truthy }
    end

    context 'without a do keyword' do
      let(:source) { 'for foo in bar; baz; end' }

      it { expect(for_node.do?).to be_falsey }
    end
  end

  describe '#void_context?' do
    context 'with a do keyword' do
      let(:source) { 'for foo in bar do baz; end' }

      it { expect(for_node.void_context?).to be_truthy }
    end

    context 'without a do keyword' do
      let(:source) { 'for foo in bar; baz; end' }

      it { expect(for_node.void_context?).to be_truthy }
    end
  end

  describe '#variable' do
    let(:source) { 'for foo in :bar; :baz; end' }

    it { expect(for_node.variable.lvasgn_type?).to be(true) }
  end

  describe '#collection' do
    let(:source) { 'for foo in :bar; baz; end' }

    it { expect(for_node.collection.sym_type?).to be(true) }
  end

  describe '#body' do
    let(:source) { 'for foo in bar; :baz; end' }

    it { expect(for_node.body.sym_type?).to be(true) }
  end

  describe '#post_condition_loop?' do
    let(:source) { 'for foo in bar; baz; end' }

    it { expect(for_node.post_condition_loop?).to be_falsey }
  end

  describe '#loop_keyword?' do
    let(:source) { 'for foo in bar; baz; end' }

    it { expect(for_node.loop_keyword?).to be_truthy }
  end
end

==> ruby-rubocop-ast_1.24.0.orig.tar.gz: rubocop-ast-1.24.0/spec/rubocop/ast/for_node_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::AST::ForNode do
  subject(:for_node) { parse_source(source).ast }

  describe '.new' do
    let(:source) { 'for foo in bar; baz; end' }

    it { is_expected.to be_a(described_class) }
  end

  describe '#keyword' do
    let(:source) { 'for foo in bar; baz; end' }

    it { expect(for_node.keyword).to eq('for') }
  end

  describe '#do?' do
    context 'with a do keyword' do
      let(:source) { 'for foo in bar do baz; end' }

      it { is_expected.to be_do }
    end

    context 'without a do keyword' do
      let(:source) { 'for foo in bar; baz; end' }

      it { is_expected.not_to be_do }
    end
  end

  describe '#void_context?' do
    context 'with a do keyword' do
      let(:source) { 'for foo in bar do baz; end' }

      it { is_expected.to be_void_context }
    end

    context 'without a do keyword' do
      let(:source) { 'for foo in bar; baz; end' }

      it { is_expected.to be_void_context }
    end
  end

  describe '#variable' do
    let(:source) { 'for foo in :bar; :baz; end' }

    it { expect(for_node.variable).to be_lvasgn_type }
  end

  describe '#collection' do
    let(:source) { 'for foo in :bar; baz; end' }

    it { expect(for_node.collection).to be_sym_type }
  end

  describe '#body' do
    let(:source) { 'for foo in bar; :baz; end' }

    it { expect(for_node.body).to be_sym_type }
  end

  describe '#post_condition_loop?' do
    let(:source) { 'for foo in bar; baz; end' }

    it { is_expected.not_to be_post_condition_loop }
  end

  describe '#loop_keyword?' do
    let(:source) { 'for foo in bar; baz; end' }

    it { is_expected.to be_loop_keyword }
  end
end
